@@ -10,24 +10,32 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
+# pylint: disable=wrong-import-position
 
 """Nobody inspects the spammish repetition."""
 
 from __future__ import annotations
 
+import os
 import sys
 import warnings
 
-if sys.flags.dev_mode and not sys.warnoptions:
+if sys.flags.dev_mode and not (
+    len(sys.warnoptions) > 1
+    or "PYTHONWARNINGS" in os.environ
+    or " -W" in " ".join(sys.orig_argv)
+):
     warnings.simplefilter("error", DeprecationWarning)
 warnings.filterwarnings("ignore", module="defusedxml")
+warnings.filterwarnings("default", module="aioredis.connection")
 
 
-from . import patches  # pylint: disable=wrong-import-position  # noqa: E402
+from . import patches
 
 patches.apply()
 
 
-from .main import main  # pylint: disable=wrong-import-position  # noqa: E402
+from .main import main
 
-sys.exit(main())
+if __name__ == "__main__":
+    sys.exit(main())
