@@ -114,7 +114,7 @@ class Backdoor(APIRequestHandler):
         try:  # pylint: disable=line-too-long
             return min(  # type: ignore[no-any-return]
                 int(
-                    self.request.headers.get("X-Pickle-Protocol")  # type: ignore[arg-type]  # noqa: B950
+                    self.request.headers.get("X-Pickle-Protocol"), base=0  # type: ignore[arg-type]  # noqa: B950
                 ),
                 pickle.HIGHEST_PROTOCOL,
             )
