@@ -17,12 +17,12 @@
 
 from __future__ import annotations
 
-import re
-from xml.etree.ElementTree import parse
+import regex
+from defusedxml.etree.ElementTree import parse
 
 if __name__ == "__main__":  # noqa: C901
     # how to get the file:
-    # download : https://dumps.wikimedia.org
+    # download: https://dumps.wikimedia.org
     # /dewiktionary/latest/dewiktionary-latest-pages-meta-current.xml.bz2
     # extract the .xml file
     xml = parse("dewiktionary-20210920-pages-meta-current.xml")
@@ -31,15 +31,15 @@ if __name__ == "__main__":  # noqa: C901
 
     titles = set()
 
-    for el in xml.iter():  # noqa: C901  # pylint: disable=too-complex
-        if el.tag != f"{pre}text":
+    for element in xml.iter():  # noqa: C901  # pylint: disable=too-complex
+        if element.tag != f"{pre}text":
             continue
         # == ōrdo ({{Sprache|Latein}}) ==
         title_line = None
         # === {{Wortart|Substantiv|Latein}}, {{m}} ===
         info_line = None
-        for _str in el.itertext():
-            for line in _str.split("\n"):
+        for string in element.itertext():
+            for line in string.split("\n"):
                 line = line.strip()
                 if not line.startswith("==") or not line.endswith("=="):
                     # print("no == ... ==", len(line), line)
@@ -138,7 +138,7 @@ if __name__ == "__main__":  # noqa: C901
             continue
         # fix string "[[text|test]] [[wort]] [[dies ist ein satz]] wörter"
         # to         "text wort dies ist ein satz wörter"
-        title = re.sub(r"\[\[([^]|]+)(?:\|[^]]+)?]]", r"\1", title)
+        title = regex.sub(r"\[\[([^]|]+)(?:\|[^]]+)?]]", r"\1", title)
         titles.add(title)
 
     with open("output.txt", "w", encoding="utf-8") as file:
