@@ -20,6 +20,7 @@ import asyncio
 import importlib
 import logging
 import os
+import platform
 import signal
 import ssl
 import sys
@@ -70,7 +71,14 @@ from .utils.base_request_handler import BaseRequestHandler
 from .utils.logging import WebhookFormatter, WebhookHandler
 from .utils.request_handler import NotFoundHandler
 from .utils.static_file_handling import StaticFileHandler
-from .utils.utils import Handler, ModuleInfo, Permission, Timer, time_function
+from .utils.utils import (
+    Handler,
+    ModuleInfo,
+    Permission,
+    Timer,
+    geoip,
+    time_function,
+)
 
 IGNORED_MODULES = {
     "backdoor.client",
@@ -286,7 +294,9 @@ def make_app(config: ConfigParser) -> str | Application:
         ),
         websocket_ping_interval=10,
         # Template settings
+        autoescape="xhtml_escape",
         template_path=TEMPLATES_DIR,
+        template_whitespace="oneline",
     )
 
 
@@ -774,9 +784,10 @@ def main() -> None | int | str:  # noqa: C901  # pragma: no cover
 
     logger.info("Starting %s %s", NAME, VERSION)
 
-    if sys.platform == "win32":
+    if platform.system() == "Windows":
         logger.warning(
-            "Please note that running on Windows is not officially supported"
+            "Please note that running %s on Windows is not officially supported",
+            NAME,
         )
 
     ignore_modules(CONFIG)
@@ -844,6 +855,7 @@ def main() -> None | int | str:  # noqa: C901  # pragma: no cover
         del AUTHORS_CACHE.control.created_by_ultra  # type: ignore[attr-defined]
         del QUOTES_CACHE.control.created_by_ultra  # type: ignore[attr-defined]
         del WRONG_QUOTES_CACHE.control.created_by_ultra  # type: ignore[attr-defined]
+        del geoip.__kwdefaults__["caches"].control.created_by_ultra
 
     task_id = tornado.process.task_id()
 
