@@ -18,7 +18,6 @@ from __future__ import annotations
 import dataclasses
 import email.utils
 import logging
-import random
 from datetime import date, datetime, timedelta, timezone
 from typing import Any
 
@@ -79,23 +78,6 @@ class QuoteOfTheDayData:
     wrong_quote: WrongQuote
     url_without_path: str
 
-    def get_quote_as_str(self, new_line_char: str = "\n") -> str:
-        """Get the quote as a string with new line."""
-        return (
-            f"»{self.wrong_quote.quote}«{new_line_char}"
-            f"- {self.wrong_quote.author}"
-        )
-
-    def get_quote_url(self) -> str:
-        """Get the URL of the quote."""
-        return (
-            f"{self.url_without_path}/zitate/{self.wrong_quote.get_id_as_str()}"
-        )
-
-    def get_quote_image_url(self) -> str:
-        """Get the URL of the image of the quote."""
-        return self.get_quote_url() + ".gif"
-
     def get_date_for_rss(self) -> str:
         """Get the date as specified in RFC 2822."""
         return email.utils.format_datetime(
@@ -108,6 +90,23 @@ class QuoteOfTheDayData:
             True,
         )
 
+    def get_quote_as_str(self, new_line_char: str = "\n") -> str:
+        """Get the quote as a string with new line."""
+        return (
+            f"»{self.wrong_quote.quote}«{new_line_char}"
+            f"- {self.wrong_quote.author}"
+        )
+
+    def get_quote_image_url(self) -> str:
+        """Get the URL of the image of the quote."""
+        return self.get_quote_url() + ".gif"
+
+    def get_quote_url(self) -> str:
+        """Get the URL of the quote."""
+        return (
+            f"{self.url_without_path}/zitate/{self.wrong_quote.get_id_as_str()}"
+        )
+
     def get_title(self) -> str:
         """Get the title for the quote of the day."""
         return f"Das Zitat des Tages vom {self.date:%d. %m. %Y}"
@@ -125,35 +124,6 @@ class QuoteOfTheDayData:
 class QuoteOfTheDayBaseHandler(QuoteReadyCheckHandler):
     """The base request handler for the quote of the day."""
 
-    def get_redis_used_key(self, wq_id: str) -> str:
-        """Get the Redis used key."""
-        return f"{self.redis_prefix}:quote-of-the-day:used:{wq_id}"
-
-    def get_redis_quote_date_key(self, wq_date: date) -> str:
-        """Get the Redis key for getting quotes by date."""
-        return f"{self.redis_prefix}:quote-of-the-day:by-date:{wq_date.isoformat()}"
-
-    async def has_been_used(self, wq_id: str) -> None | bool:
-        """Check with Redis here."""
-        if not EVENT_REDIS.is_set():
-            return None
-        return bool(await self.redis.get(self.get_redis_used_key(wq_id)))
-
-    async def set_used(self, wq_id: str) -> None:
-        """Set Redis key with used state and TTL here."""
-        if not EVENT_REDIS.is_set():
-            return
-        await self.redis.setex(
-            self.get_redis_used_key(wq_id),
-            #  we have over 720 funny wrong quotes, so 420 should be ok
-            420 * 24 * 60 * 60,  # TTL
-            1,  # True
-        )
-
-    def get_scheme_and_netloc(self) -> str:
-        """Get the beginning of the URL."""
-        return f"{self.request.protocol}://{self.request.host}"
-
     async def get_quote_by_date(
         self, wq_date: date | str
     ) -> None | QuoteOfTheDayData:
@@ -162,7 +132,7 @@ class QuoteOfTheDayBaseHandler(QuoteReadyCheckHandler):
             return None
 
         if isinstance(wq_date, str):
-            wq_date = date(*tuple(int(x) for x in wq_date.split("-")))
+            wq_date = date.fromisoformat(wq_date)
 
         wq_id = await self.redis.get(self.get_redis_quote_date_key(wq_date))
         if not wq_id:
@@ -179,35 +149,59 @@ class QuoteOfTheDayBaseHandler(QuoteReadyCheckHandler):
         """Get the quote for today."""
         if not EVENT_REDIS.is_set():
             return None
-        today = datetime.now(tz=timezone.utc).date()
+        today = datetime.utcnow().date()
         quote_data = await self.get_quote_by_date(today)
         if quote_data:  # if was saved already
             return quote_data
         quotes: tuple[WrongQuote, ...] = get_wrong_quotes(
-            lambda wq: wq.rating > 1
+            lambda wq: wq.rating > 1, shuffle=True
         )
         if not quotes:
-            logger.warning("No quotes available!")
+            logger.warning("No quotes available")
             return None
-        count = len(quotes)
-        index = random.randrange(0, count)
-        for _ in range(count - 1):
-            quote = quotes[index]
+        for quote in quotes:
             if await self.has_been_used(quote.get_id_as_str()):
-                index = (index + 1) % count
-            else:
-                wq_id = quote.get_id_as_str()
-                await self.set_used(wq_id)
-                await self.redis.setex(
-                    self.get_redis_quote_date_key(today),
-                    420 * 24 * 60 * 60,  # TTL
-                    wq_id,
-                )
-                return QuoteOfTheDayData(
-                    today, quote, self.get_scheme_and_netloc()
-                )
+                continue
+            wq_id = quote.get_id_as_str()
+            await self.set_used(wq_id)
+            await self.redis.setex(
+                self.get_redis_quote_date_key(today),
+                60 * 60 * 24 * 420,  # TTL
+                wq_id,
+            )
+            return QuoteOfTheDayData(today, quote, self.get_scheme_and_netloc())
+        logger.critical("Failed to generate a new quote of the day")
         return None
 
+    def get_redis_quote_date_key(self, wq_date: date) -> str:
+        """Get the Redis key for getting quotes by date."""
+        return f"{self.redis_prefix}:quote-of-the-day:by-date:{wq_date.isoformat()}"
+
+    def get_redis_used_key(self, wq_id: str) -> str:
+        """Get the Redis used key."""
+        return f"{self.redis_prefix}:quote-of-the-day:used:{wq_id}"
+
+    def get_scheme_and_netloc(self) -> str:
+        """Get the beginning of the URL."""
+        return f"{self.request.protocol}://{self.request.host}"
+
+    async def has_been_used(self, wq_id: str) -> None | bool:
+        """Check with Redis here."""
+        if not EVENT_REDIS.is_set():
+            return None
+        return bool(await self.redis.get(self.get_redis_used_key(wq_id)))
+
+    async def set_used(self, wq_id: str) -> None:
+        """Set Redis key with used state and TTL here."""
+        if not EVENT_REDIS.is_set():
+            return
+        await self.redis.setex(
+            self.get_redis_used_key(wq_id),
+            #  we have over 720 funny wrong quotes, so 420 should be ok
+            60 * 60 * 24 * 420,  # TTL
+            1,  # True
+        )
+
 
 class QuoteOfTheDayRss(QuoteOfTheDayBaseHandler):
     """The request handler for the quote of the day RSS feed."""
@@ -219,12 +213,12 @@ class QuoteOfTheDayRss(QuoteOfTheDayBaseHandler):
         """Handle GET requests."""
         if head:
             return
-        today = datetime.now(tz=timezone.utc).date()
+        today = datetime.utcnow().date()
         quotes = (
             await self.get_quote_of_today(),
             *[
                 await self.get_quote_by_date(today - timedelta(days=i))
-                for i in range(1, 5)
+                for i in range(1, 8)
             ],
         )
         await self.render(
@@ -243,6 +237,9 @@ class QuoteOfTheDayAPI(APIRequestHandler, QuoteOfTheDayBaseHandler):
         head: bool = False,  # pylint: disable=unused-argument
     ) -> None:
         """Handle GET requests."""
+        if not EVENT_REDIS.is_set():
+            raise HTTPError(503)
+
         quote_data = await (
             self.get_quote_by_date(date_str)
             if date_str
@@ -250,7 +247,7 @@ class QuoteOfTheDayAPI(APIRequestHandler, QuoteOfTheDayBaseHandler):
         )
 
         if not quote_data:
-            raise HTTPError(404)
+            raise HTTPError(404 if date_str else 503)
 
         if self.request.path.endswith("/full"):
             return await self.finish(quote_data.to_json())
@@ -276,6 +273,9 @@ class QuoteOfTheDayRedirect(QuoteOfTheDayBaseHandler):
         head: bool = False,  # pylint: disable=unused-argument
     ) -> None:
         """Handle GET requests."""
+        if not EVENT_REDIS.is_set():
+            raise HTTPError(503)
+
         wrong_quote_data = await (
             self.get_quote_by_date(date_str)
             if date_str
@@ -283,7 +283,7 @@ class QuoteOfTheDayRedirect(QuoteOfTheDayBaseHandler):
         )
 
         if not wrong_quote_data:
-            raise HTTPError(404)
+            raise HTTPError(404 if date_str else 503)
 
         self.redirect(
             self.fix_url(
