@@ -1,5 +1,5 @@
 // @license magnet:?xt=urn:btih:0b31508aeb0634b347b8270c7bee4d411b5d4109&dn=agpl-3.0.txt GNU-AGPL-3.0-or-later
-(()=>{const textInput=elById("text");const configInput=elById("config-textarea");const outputText=elById("output");const errorText=elById("error-msg");if(errorText.innerHTML.trim())
+"use strict";(()=>{const textInput=elById("text");const configInput=elById("config-textarea");const outputText=elById("output");const errorText=elById("error-msg");if(errorText.innerHTML.trim())
 alert(errorText.innerHTML.trim());function onerror(e){error(e);if(e.error){alert(e.error);errorText.innerText=`${e.error} In line ${e.line_num}: "${e.line}"`;}else{alert(e);errorText.innerText=e;}}
 function ondata(data,onpopstate=false){if(!data){log("data is falsy!")
 return;}
