@@ -19,6 +19,7 @@ This should only contain the BaseRequestHandler class.
 
 from __future__ import annotations
 
+import contextlib
 import inspect
 import logging
 import random
@@ -53,6 +54,7 @@ from .. import EVENT_ELASTICSEARCH, EVENT_REDIS, NAME, ORJSON_OPTIONS
 from .static_file_handling import FILE_HASHES_DICT
 from .utils import (
     THEMES,
+    BumpscosityValue,
     ModuleInfo,
     OpenMojiValue,
     Permission,
@@ -61,6 +63,7 @@ from .utils import (
     bool_to_str,
     geoip,
     hash_bytes,
+    parse_bumpscosity,
     parse_openmoji_arg,
     ratelimit,
     str_to_bool,
@@ -221,13 +224,18 @@ class BaseRequestHandler(RequestHandler):
         path = url.path if new_path is None else new_path  # the path of the url
         if path.startswith("/soundboard/files/") or path in FILE_HASHES_DICT:
             query_args.update(
-                no_3rd_party=None, theme=None, dynload=None, openmoji=None
+                no_3rd_party=None,
+                theme=None,
+                dynload=None,
+                openmoji=None,
+                bumpscosity=None,
             )
         else:
             query_args.setdefault("no_3rd_party", self.get_no_3rd_party())
             query_args.setdefault("theme", self.get_theme())
             query_args.setdefault("dynload", self.get_dynload())
             query_args.setdefault("openmoji", self.get_openmoji())
+            query_args.setdefault("bumpscosity", self.get_bumpscosity())
             if query_args["no_3rd_party"] == self.get_saved_no_3rd_party():
                 query_args["no_3rd_party"] = None
             if query_args["theme"] == self.get_saved_theme():
@@ -236,6 +244,8 @@ class BaseRequestHandler(RequestHandler):
                 query_args["dynload"] = None
             if query_args["openmoji"] == self.get_saved_openmoji():
                 query_args["openmoji"] = None
+            if query_args["bumpscosity"] == self.get_saved_bumpscosity():
+                query_args["bumpscosity"] = None
 
         return add_args_to_url(
             urlunsplit(
@@ -254,13 +264,17 @@ class BaseRequestHandler(RequestHandler):
         self,
         ip: None | str = None,  # pylint: disable=invalid-name
         database: str = geoip.__defaults__[0],  # type: ignore
+        *,
+        allow_fallback: bool = True,
     ) -> Coroutine[None, None, None | dict[str, Any]]:
         """Get GeoIP information."""
         if not ip:
-            ip = str(self.request.remote_ip)
+            ip = self.request.remote_ip
         if not EVENT_ELASTICSEARCH.is_set():
             return geoip(ip, database)
-        return geoip(ip, database, self.elasticsearch)
+        return geoip(
+            ip, database, self.elasticsearch, allow_fallback=allow_fallback
+        )
 
     @classmethod
     def get_allowed_methods(cls) -> list[str]:
@@ -285,6 +299,12 @@ class BaseRequestHandler(RequestHandler):
         except ValueError as err:
             raise HTTPError(400, f"{value} is not a boolean") from err
 
+    def get_bumpscosity(self) -> BumpscosityValue:
+        """Get the saved value for the bumpscosity."""
+        if spam := self.get_argument("bumpscosity", ""):
+            return parse_bumpscosity(spam)
+        return self.get_saved_bumpscosity()
+
     def get_display_theme(self) -> str:
         """Get the theme currently displayed."""
         if "random" not in (theme := self.get_theme()):
@@ -359,18 +379,19 @@ class BaseRequestHandler(RequestHandler):
         min_: None | int = None,
     ) -> int:
         """Get an argument parsed as integer."""
-        value: int
         if default is None:
             str_value = self.get_argument(name)
             try:
-                value = int(str_value)
+                value = int(str_value, base=0)
             except ValueError as err:
                 raise HTTPError(400, f"{str_value} is not an integer") from err
-        else:
+        elif self.get_argument(name, ""):
             try:
-                value = int(self.get_argument(name, None) or default)
+                value = int(self.get_argument(name), base=0)
             except ValueError:
                 value = default
+        else:
+            value = default
 
         if max_ is not None:
             value = min(max_, value)
@@ -410,6 +431,10 @@ class BaseRequestHandler(RequestHandler):
 
         return f"{self.request.protocol}://{self.request.host}{endpoint}"
 
+    def get_saved_bumpscosity(self) -> BumpscosityValue:
+        """Get the saved value for the bumpscosity."""
+        return parse_bumpscosity(self.get_cookie("bumpscosity", ""))
+
     def get_saved_dynload(self) -> bool:
         """Get the saved value for dynload."""
         return str_to_bool(self.get_cookie("dynload"), False)
@@ -640,7 +665,7 @@ class BaseRequestHandler(RequestHandler):
                 logger.warning(
                     "Unauthorized access to %s from %s",
                     self.request.path,
-                    anonymize_ip(str(self.request.remote_ip)),
+                    anonymize_ip(self.request.remote_ip),
                 )
                 raise HTTPError(401 if is_authorized is None else 403)
 
@@ -816,8 +841,8 @@ class BaseRequestHandler(RequestHandler):
             "style-src 'self' 'unsafe-inline';"
             "img-src 'self' https://img.zeit.de https://github.asozial.org;"
             "frame-ancestors 'self';"
-            "sandbox allow-downloads allow-forms allow-popups allow-scripts"
-            " allow-top-navigation-by-user-activation allow-same-origin;"
+            "sandbox allow-downloads allow-same-origin allow-popups allow-scripts"
+            " allow-top-navigation-by-user-activation allow-forms  allow-modals;"
             "report-to default;"
             + (
                 f"report-uri {self.get_reporting_api_endpoint()};"
@@ -929,4 +954,17 @@ class BaseRequestHandler(RequestHandler):
         if isinstance(chunk, dict):
             chunk = self.dump(chunk)
 
+        if self.now.date() == date(self.now.year, 4, 27):
+            if isinstance(chunk, bytes):
+                with contextlib.suppress(UnicodeDecodeError):
+                    chunk = chunk.decode("utf-8")
+            if isinstance(chunk, str):
+                chunk = regex.sub(
+                    r"\b\p{Lu}\p{Ll}{4}\p{Ll}*\b",
+                    lambda match: "Stanley"
+                    if random.Random(match[0]).randrange(5) == self.now.year % 5
+                    else match[0],
+                    chunk,
+                )
+
         super().write(chunk)
